/testing/guestbin/swan-prep
#add address from to be extruded subnet on road.
ipsec start
../../guestbin/wait-until-pluto-started
echo "initdone"
